{% from "globals.jinja2" import button %}
{% from "pydantic_form/widget.jinja2" import show_widget %}
{% call show_widget(widget) %}
<div id="{{widget.id}}" class="m-4">
  <details open>
    <summary class="justify-between items-center font-medium cursor-pointer">
      <h4 class="inline font-sans text-3xl font-bold">{{widget.title}}</h4>
    </summary>
    <div>
      {% for child in children_widget %}
      {{ child }}
      {% endfor %}
    </div>
  </details>
</div>
{% endcall %}
